@@ -8,7 +8,7 @@ import requests
 from alira.instance import Instance
 from alira.modules.module import Retriable, ServiceException, Module
 
-from botocore.exceptions import ClientError, EndpointConnectionError
+from botocore.exceptions import EndpointConnectionError
 
 from twilio.rest import Client
 from twilio.base.exceptions import TwilioRestException
@@ -262,7 +262,8 @@ class SocketIO(Module):
             return
 
         logging.info(
-            f"Sending Socket IO notification to {self.endpoint}. Namespace: {self.pipeline_id}"
+            f"Sending Socket IO notification to {self.endpoint}. "
+            f"Namespace: {self.pipeline_id}"
         )
 
         payload["event"] = event
