@@ -83,11 +83,13 @@ class Pipeline(object):
                 **arguments,
             )
 
-        return Store.configure(
+        stored_instance = Store.configure(
             configuration_directory=self.configuration_directory,
             store_configuration=self.store_configuration,
         ).get(instance.id)
 
+        return stored_instance or instance
+
     @classmethod
     def run_module(
         self,
@@ -152,40 +154,24 @@ class Pipeline(object):
                 logging.info(f"Loaded {python_filename} as module {module_name}")
             except Exception:
                 logging.exception(
-                    f"There was an error loading {python_filename} as module {module_name}"
+                    f"There was an error loading {python_filename} "
+                    f"as module {module_name}"
                 )
 
     def _load_pipeline_configuration(self, pipeline_configuration):
         if pipeline_configuration is None:
-            logging.info(
-                "Configured a default pipeline since no specific configuration "
-                "was specified."
+            pipeline_configuration = os.path.join(
+                self.configuration_directory, PIPELINE_FILENAME
             )
-            self.pipeline_id = "default"
-            self.modules = []
-            return
 
         if hasattr(pipeline_configuration, "read"):
-            try:
-                pipeline_configuration = yaml.safe_load(pipeline_configuration.read())
-            except Exception as e:
-                logging.exception(e)
-                raise RuntimeError("Unable to load pipeline configuration") from e
+            pipeline_configuration = self._load_pipeline_configuration_from_stream(
+                pipeline_configuration
+            )
         else:
-            logging.info(
-                f"Loading pipeline configuration from {pipeline_configuration}..."
+            pipeline_configuration = self._load_pipeline_configuration_from_file(
+                pipeline_configuration
             )
-
-            try:
-                with open(pipeline_configuration) as file:
-                    pipeline_configuration = yaml.load(
-                        file.read(), Loader=yaml.FullLoader
-                    )
-            except Exception as e:
-                logging.exception(e)
-                raise RuntimeError(
-                    f"Unable to load pipeline configuration from file {pipeline_configuration}"
-                ) from e
 
         self.pipeline_id = pipeline_configuration.get("name", None)
         if self.pipeline_id is None:
@@ -222,3 +208,23 @@ class Pipeline(object):
 
             arguments.update(self.kwargs)
             self.modules.append(module(**arguments))
+
+    def _load_pipeline_configuration_from_stream(self, pipeline_configuration):
+        try:
+            return yaml.safe_load(pipeline_configuration.read())
+        except Exception as e:
+            logging.exception(e)
+            raise RuntimeError("Unable to load pipeline configuration") from e
+
+    def _load_pipeline_configuration_from_file(self, pipeline_configuration):
+        logging.info(f"Loading pipeline configuration from {pipeline_configuration}...")
+
+        try:
+            with open(pipeline_configuration) as file:
+                return yaml.load(file.read(), Loader=yaml.FullLoader)
+        except Exception as e:
+            logging.exception(e)
+            raise RuntimeError(
+                "Unable to load pipeline configuration from "
+                f"file {pipeline_configuration}"
+            ) from e
